__title__ = 'A_Api_Server'
__description__ = '自建一个Resful风格的接口自助服务，方便API自动化测试工具的开发与调试！'
__keywords__ = 'ApiServer, Api, MockServer, Api Test, 接口测试, 接口自动化测试'
__url__ = 'https://github.com/zhuifengshen/a-api-server'
__version__ = '1.1.2'
__author__ = 'devin'
__author_email__ = '1324556701@qq.com'
__license__ = 'MIT'
__cake__ = u'\u2728 \U0001f370 \u2728'
